@@ -1,15 +1,16 @@
 
 from itertools import chain
 
-from generallibrary import deco_cache
+from generallibrary import deco_cache, flatten
 
-from generalpackager.api.localrepo.base.localrepo_target import _LocalRepo_Target
+from generalpackager.api.localrepo.base.localrepo_target import Targets
 
 
-class Packages(_LocalRepo_Target.Targets):
-    """ Names of all general packages categorized by target.
+class Packages(Targets):
+    """ Purpose is to easily see if name is general and what target it has.
         Todo: Generate Python file in generalpackager containing general packages. """
     python = [
+        "generalimport",
         "generallibrary",
         "generalfile",
         "generalvector",
@@ -31,5 +32,5 @@ class Packages(_LocalRepo_Target.Targets):
     @classmethod
     @deco_cache()
     def all_packages(cls):
-        return list(chain(*cls.field_values_defaults()))
+        return flatten(cls.field_values_defaults())
 
